"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const devtools_1 = __importDefault(require("@vue/devtools"));
const core_1 = require("@nativescript/core");
const toasty = __importStar(require("@triniwiz/nativescript-toasty"));
const nsSocketIo = __importStar(require("@triniwiz/nativescript-socketio"));
if (!global.performance) {
    global.performance = {};
}
if (!global.performance.now) {
    const nowOffset = Date.now();
    global.performance.now = function now() {
        return Date.now() - nowOffset;
    };
}
if (!global.requestAnimationFrame) {
    global.requestAnimationFrame = function raf(cb) {
        return setTimeout(cb, 1000 / 60);
    };
}
// fixes a crash when running VueDevtools
if (!global.HTMLElement) {
    global.HTMLElement = function () {
        return false;
    };
}
/**
 * Returns the correct address for the host machine when running on emulator
 */
const getServerIpAddress = (host, port) => {
    if (host) {
        return `${host}:${port}`;
    }
    if (core_1.isAndroid) {
        // @ts-ignore
        const FINGERPRINT = android.os.Build.FINGERPRINT;
        if (FINGERPRINT.includes("vbox")) {
            // running on genymotion
            return `10.0.3.2:${port}`;
        }
        else if (FINGERPRINT.includes("generic")) {
            // running on android emulator
            return `10.0.2.2:${port}`;
        }
    }
    // ios simulator uses localhost
    return `127.0.0.1:${port}`;
};
// Wrap the toast message in a try, devtool still work without toaster
const showToast = (message) => {
    try {
        const { Toasty } = toasty;
        new Toasty({
            text: message,
            backgroundColor: "#53ba82",
            yAxisOffset: 50,
        }).show();
    }
    catch (error) {
        console.log(error);
    }
};
const install = (Vue, { debug = false, host = null, port = 8098 } = {}) => {
    // ensure all dependencies are available and bail out if anything is missing
    try {
        require.resolve("@vue/devtools");
    }
    catch (e) {
        console.log("[nativescript-vue-devtools] skipping install due to missing dependencies.\n\n", e, "\n\n");
        return;
    }
    const startApp = Vue.prototype.$start;
    Vue.prototype.$start = function () {
        const setupDevtools = () => {
            const options = {
                app: this,
                showToast,
                io() {
                    try {
                        const { SocketIO } = nsSocketIo;
                        const address = `http://${getServerIpAddress(host, port)}`;
                        // this line causes a crash. the socketio plugin needs to be updated to nativescript version 8.0
                        let socketIO = new SocketIO(address, { debug: debug });
                        socketIO.connect();
                        return socketIO;
                    }
                    catch (error) {
                        console.log(error);
                        // prevent crashing by returning a noop stub
                        return {
                            on() { },
                            emit() { },
                        };
                    }
                },
            };
            // vue-dev-tools type files are outdated so this is to get around that
            devtools_1.default.connect("ws://localhost", port, options);
            devtools_1.default.init(Vue);
        };
        if (core_1.isAndroid) {
            setupDevtools();
        }
        else {
            // on ios we need to delay the call because the socket connection is not established
            // if called too early in the application startup process
            // we might need to add a delay to the setTimeout in the future
            setTimeout(setupDevtools);
        }
        return startApp.call(this);
    };
};
exports.default = {
    install,
};
//# sourceMappingURL=index.js.map